A browser-based frontend for GDB
====================================

.. figure:: https://github.com/cs01/gdbgui/raw/master/screenshots/gdbgui.png
   :alt: gdbgui

.. image:: https://travis-ci.org/cs01/gdbgui.svg?branch=master
  :target: https://travis-ci.org/cs01/gdbgui

.. image:: https://img.shields.io/badge/pypi-0.10.2.1-blue.svg
  :target: https://pypi.python.org/pypi/gdbgui/

.. image:: https://img.shields.io/badge/python-2.7,3.4,3.5,3.6,pypy-blue.svg
  :target: https://pypi.python.org/pypi/gdbgui/

.. image:: https://img.shields.io/badge/homepage-gdbgui.com-blue.svg
  :target: https://gdbgui.com

A modern, browser-based frontend to gdb (gnu debugger). Add breakpoints, view stack traces, and more in C, C++, Go, and Rust! Simply run ``gdbgui`` from the terminal and a new tab will open in your browser.


Homepage
--------
`gdbgui.com <https://gdbgui.com>`_ for documentation, installation instructions, screenshots and more

License
-------
GNU GPLv3

PyPI, this github page, and gdbgui.com are the only official sources of gdbgui.

Contributing
------------

See `CONTRIBUTING <https://github.com/cs01/gdbgui/blob/master/CONTRIBUTING.md>`_

Authors
-------
``gdbgui`` is primarily authored by Chad Smith, but would not be possible without `contributions from the community <https://github.com/cs01/gdbgui/graphs/contributors>`_ and several amazing open source libraries.

JavaScript

- React
- splitjs: https://github.com/nathancahill/Split.js
- awesomplete: https://github.com/LeaVerou/awesomplete
- vis.js: http://visjs.org/
- moment.js
- lodash
- bootstrap
- jquery

Python

- flask: http://flask.pocoo.org/
- socket.io: https://socket.io/
- flask-socket-io: https://flask-socketio.readthedocs.io/en/latest/
- Pygments: http://pygments.org/
- gevent: http://www.gevent.org/
- pygdbmi: https://github.com/cs01/pygdbmi


Users of gdbgui
--------------------------------

- `Arch Linux <https://www.archlinux.org/>`_
- `BlackArch Linux <https://www.blackarch.org/>`_
- `FreeBSD <https://www.freebsd.org/>`_
- Create a PR and add your company, name, school, project, etc. here

Contact
-------
grassfedcode@gmail.com
